CreateHooks class

install hooks

Constructors

CreateHooks()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

copyFile({String? targetPath}) → Future<bool>
Create files to .git/hooks and targetPath
getTargetFilePath() → Future<String?>
get target file path. returns the path that the git hooks points to.