Utils class

utils class

Constructors

Utils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

gitHookFolder → String
get git hooks folder
no setter

Static Methods

getCommitEditMsg() → String
get commit edit msg from '.git/COMMIT_EDITMSG'
getOwnPath() → String?
get path of git_hooks library
setGitHooksFolder(String path) → void
test create git hooks file
uri(String filePath) → String
check the file Path